Skip to main content

ConfMerge - Python3 configuration file merge utility

ConfMerge lets you merge multiple configuration files into one file. Currently supported file formats are INI, YAML and JSON.

Table of contents:


Installation

To install ConfMerge directly from Github:

pip install git+https://github.com/Aisbergg/python-confmerge@v0.2.0

Usage

usage: confmerge [-d] [-f] [-h] [-m MODE] [-t FILE_TYPE] [--debug] [--version]
                 src [src ...] dest

Merge multiple configuration files into one file

positional arguments:
  src                   The source files
  dest                  The destination file

optional arguments:
  -d, --dry-run         Print the merged content on stdout instead of writing
                        it to the destination file
  -f, --force           Force overwriting of any existing destination file
  -h, --help            Show this help message and exit
  -m MODE, --mode MODE  File mode for newly created files
  -t FILE_TYPE, --type FILE_TYPE
                        Type of file can be one of 'ini', 'json' or 'yaml'. If
                        not specified the type will be guessed from the file
                        extension
  --debug               Print debug trace on error
  --version             Print the program version and exit

Examples

Merge multiple INI files and write result into res.ini

confmerge -f 1.ini 2.ini 3.ini res.ini

Merge different types of configuration files:

confmerge -f 1.yml 2.json 3.ini res.yml

Perform a dry run (don't write output file but print result on stdout):

confmerge --dry-run 1.yml 2.yml not-touched.yml

License

ConfMerge is released under the LGPL v3 License. See LICENSE.txt for more information.

Metadata

Release files for ConfMerge 0.2.0

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for ConfMerge 0.2.0
File Size Uploaded
ConfMerge-0.2.0.tar.gz 5.1 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for ConfMerge 0.2.0
File Interpreter ABI Platform
ConfMerge-0.2.0-py3-none-any.whl Python 3 none any Details

Total release size: 12.9 kB

Release files / ConfMerge-0.2.0.tar.gz

Download URL ConfMerge-0.2.0.tar.gz
Size 5.1 kB
Tags Source
SHA-256 checksum
How to use checksums
12f08f311e97517a9f9f6b34be0cac6febd308a9e1bfeaa8e5700bdb9bbd9172
BLAKE2b-256 checksum
How to use checksums
32bb21f7ae2f2f637f873cb2747767020849d345f0e407d18e78495df21ddbfb
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No

Release files / ConfMerge-0.2.0-py3-none-any.whl

Download URL ConfMerge-0.2.0-py3-none-any.whl
Size 7.8 kB
Tags Python 3
SHA-256 checksum
How to use checksums
984d0c39047d71f58530d693bc8b0b8596cb29a63df7a424e8dac2536d2e2ad7
BLAKE2b-256 checksum
How to use checksums
a5218fd70543217171f2fca777cbf0ba97984253b37937f170ea951fd9ce4a5f
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No

Release history Release notifications | RSS feed

This release

0.2.0 This release

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page